bg_swipe_button library

Classes

BGSwipeButton
A customizable swipe button widget that changes state upon user interaction. The button includes features like gradient background, customizable icons, text, and color changes on swipe completion.