menu
bg_swipe_button package
documentation
bg_swipe_button.dart
bg_swipe_button.dart
dark_mode
light_mode
bg_swipe_button
library
Classes
BGSwipeButton
A customizable swipe button widget that changes state upon user interaction. The button includes features like gradient background, customizable icons, text, and color changes on swipe completion.
bg_swipe_button package
documentation
bg_swipe_button.dart
bg_swipe_button
package
Libraries
bg_swipe_button
bg_swipe_button library